### Run, diversity, run!
alpha.gamma(regional.dataset="regional.interactions.txt", local.datasets="loc", nsmul=10)

#######################################################################
### Função desenvolvida como projeto de final de curso BIE5782 - PPGEco - USP
### Prof. P. I. Prado e Prof. A. Adalardo de Oliveira
### Aluno: R. L. G. Raimundo
#######################################################################
alpha.gamma<-function(regional.dataset, local.datasets, nsmul) 
    
### LOAD ALL THAT HARD FIELD WORK
### The link to download the example files [from Vázquez & Simberloff (2005)]  
{
pool<-read.table(regional.dataset)
colnames(pool)<-paste("Pollinator", seq(1:dim(pool)[2]))
rownames(pool)<-paste("Plant", seq(1:dim(pool)[1]))
dir( pattern = local.datasets )->local.files
length(local.files)->lfn

###FIELD DATA
### Compute nestedness temperature for each empirical matrix
### Compute pollinator richness by plant for each emperical matrix
require(bipartite)
alpha.field.list=list()
nestedness.field.list=list()
local.list=list()
for(i in 1:lfn)
  {
      temp.table<-read.table(local.files[i])
      temp.table[temp.table>0] <- 1
      #rownames(temp.table)<-paste("Plant", seq(1:dim(temp.table)[2]))
      #colnames(temp.table)<-paste("Pollinator", seq(1:dim(temp.table)[1]))
      local.list[[i]] = temp.table
      nested(local.list[[i]], null.models=FALSE)->temperatures.field
      rowSums(local.list[[i]])->richnesses.field
   alpha.field.list[[i]]=richnesses.field
   nestedness.field.list[[i]]=temperatures.field
  }  
### A NULL MODEL FOR BIPARTITE NETWORKS (SCENARIO: LOCAL NETWORKS ARE RANDOM SAMPLES OF THE REGIONAL SPECIES POOL)
### Generate nsmul matrices according to the null model (i. e., proportionaly sample local communities from the regional pool)
### Compute nestedness temperature for each theoretical matrix
### Compute pollinator richness by plant for each theoretical matrix
alpha.list=list()
nestedness.list=list()
bascompte.list=list()
for(k in 1:nsmul)
    {
      for(u in 1:nsmul){
        ref<-read.table(regional.dataset) 
        ref[ref>0] <- 1
        margin <- ifelse(ncol(ref)< nrow(ref),2,1)
        currentweb <- matrix(0,ncol=ncol(ref),nrow=nrow(ref))
        pc <- colMeans(ref)
        pr <- rowMeans(ref)
        if(margin==2)
          {
            for(i in 1:ncol(ref))
              {
                currentweb[,i] <- (pc[i]+pr)/2
              }
          } else
        {
          for(i in 1:nrow(ref))
            {
              currentweb[i,] <- (pr[i]+pc)/2
            }
        }
        (apply(currentweb,margin,function(x)rbinom(length(x),1,x)))->expected.local
        t(expected.local)->expected.local
        bascompte.list[[u]]=expected.local
        nested(bascompte.list[[u]], null.models=FALSE)->temperatures
        rowSums(bascompte.list[[u]])->richnesses.null
     }
      alpha.list[[k]]=richnesses.null
      nestedness.list[[k]]=temperatures
    }

################### arent matrices lists cool? 
pool
pool[pool>0]<-1
pool->pool.plot
rowSums(pool)->gama.sum

gama.sum # pollinator richness for each plant at the regional scale

alpha.list # pollinator richness for each plant at the local scale (null model)
alpha.field.list # observed pollinator richness for each plant at the local scale

nestedness.field.list #nestedness temperatures for each empirical matrix
nestedness.list # nestedness temperatures for each theoretical matrix

################### Output
require(ggplot2)
#Compute mean local pollinator richness by plant (Null Model)
melt.list(alpha.list)->alpha.theor
alpha.theor$L1<-c(rep(seq(1:dim(temp.table)[1]),nsmul))
colnames(alpha.theor)<-c("Alpha", "Plant")
as.factor(alpha.theor$Plant)->alpha.theor$Plant
tapply(alpha.theor$Alpha, alpha.theor$Plant, mean)->mean.alpha.theor
tapply(alpha.theor$Alpha, alpha.theor$Plant, sd)->dp.alpha.theor

#Compute mean local pollinator richness by plant (Field Data)
melt.list(alpha.field.list)->alpha.empiric
alpha.empiric$L1<-c(rep(seq(1:dim(temp.table)[1]),lfn))
colnames(alpha.empiric)<-c("Alpha", "Plant")
as.factor(alpha.empiric$Plant)->alpha.empiric$Plant
tapply(alpha.empiric$Alpha, alpha.empiric$Plant, mean)->mean.alpha.empiric
tapply(alpha.empiric$Alpha, alpha.empiric$Plant, sd)->dp.alpha.empiric

#Melt nestedness temperatures - theoretical and empirical matrices
melt(nestedness.list)->nestedness.theor
nestedness.theor$value->z1
melt(nestedness.field.list)->nestedness.empiric
nestedness.empiric$value->z2

#Plot some figures summarizing all the job
require(bipartite)
par(mfrow=c(3,2))

plot(mean.alpha.theor~gama.sum, xlab="Regional Richness(Gama)", ylab="Mean Local Richness(Alpha)", main="Null Model")
lm(mean.alpha.theor~gama.sum)->alpha.null.m1
abline(alpha.null.m1)

plot(mean.alpha.empiric~gama.sum, xlab="Regional Richness(Gama)", ylab="Mean Local Richness(Alpha)", main="Field Data")
lm(mean.alpha.empiric~gama.sum)->alpha.empiric.m1
abline(alpha.empiric.m1)

hist(z1, prob=TRUE, main=paste("Null Model"), xlab="Local Matrices Temperature")
lines(density(z1))
hist(z2, prob=TRUE, main=paste("Field Data"), xlab="Local Matrices Temperature")
lines(density(z2))

pool.plot->pool.plot2
nestedtemp(pool.plot2)->pool.plot2
plot(pool.plot2, main="Regional Matrix and Regional Network")
pool.plot->rede
plotweb(rede, method="normal", ybig=0.8)

return()
}
